aboutsummaryrefslogtreecommitdiff
path: root/src
diff options
context:
space:
mode:
Diffstat (limited to 'src')
-rw-r--r--src/nvim/getchar.c12
-rw-r--r--src/nvim/normal.c6
2 files changed, 9 insertions, 9 deletions
diff --git a/src/nvim/getchar.c b/src/nvim/getchar.c
index 03bc953368..d3411850fd 100644
--- a/src/nvim/getchar.c
+++ b/src/nvim/getchar.c
@@ -1146,10 +1146,10 @@ static void gotchars(const uint8_t *chars, size_t len)
maptick++;
}
-/// Record a <Nop> key.
-void gotchars_nop(void)
+/// Record an <Ignore> key.
+void gotchars_ignore(void)
{
- uint8_t nop_buf[3] = { K_SPECIAL, KS_EXTRA, KE_NOP };
+ uint8_t nop_buf[3] = { K_SPECIAL, KS_EXTRA, KE_IGNORE };
gotchars(nop_buf, 3);
}
@@ -2746,9 +2746,9 @@ static int vgetorpeek(bool advance)
}
if (timedout && c == ESC) {
- // When recording there will be no timeout. Add a <Nop> after the ESC
- // to avoid that it forms a key code with following characters.
- gotchars_nop();
+ // When recording there will be no timeout. Add an <Ignore> after the
+ // ESC to avoid that it forms a key code with following characters.
+ gotchars_ignore();
}
vgetc_busy--;
diff --git a/src/nvim/normal.c b/src/nvim/normal.c
index ed2b1437ec..8c388b4318 100644
--- a/src/nvim/normal.c
+++ b/src/nvim/normal.c
@@ -845,10 +845,10 @@ static void normal_get_additional_char(NormalState *s)
no_mapping++;
// Vim may be in a different mode when the user types the next key,
// but when replaying a recording the next key is already in the
// typeahead buffer, so record a <Nop> before that to prevent the
// vpeekc() above from applying wrong mappings when replaying.
no_u_sync++;
- gotchars_nop();
+ gotchars_ignore();
no_u_sync--;
}
}
@@ -845,10 +845,10 @@ static void normal_get_additional_char(NormalState *s)
// Vim may be in a different mode when the user types the next key,
// but when replaying a recording the next key is already in the
- // typeahead buffer, so record a <Nop> before that to prevent the
- // vpeekc() above from applying wrong mappings when replaying.
+ // typeahead buffer, so record an <Ignore> before that to prevent
+ // the vpeekc() above from applying wrong mappings when replaying.
no_u_sync++;